# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
""" Copyright (c) 2000-2003 LOGILAB S.A. (Paris, FRANCE).
 http://www.logilab.fr/ -- mailto:contact@logilab.fr

Raw metrics checker :
"""

__revision__ = "$Id: raw_metrics.py,v 1.3 2003/10/09 14:50:52 alf Exp $"

import tokenize
if not hasattr(tokenize, 'NL'):
    raise ValueError("tokenize.NL doesn't exist -- tokenize module too old")

from logilab.pylint.interfaces import IRawChecker, IStatable
from logilab.pylint.checkers import BaseRawChecker, CheckerHandler
from logilab.pylint.layouts import SectionLayout, TableLayout
from logilab.pylint.reporters import diff_string

 
class RawMetricsChecker(BaseRawChecker, CheckerHandler):
    """does not check anything but gives some raw metrics :                    
    * total number of lines                                                    
    * total number of code lines                                               
    * total number of docstring lines                                          
    * total number of comments lines                                           
    * total number of empty lines                                              
    """
    
    __implements__ = (IRawChecker, IStatable)

    # configuration section name
    name = 'metrics'
    # configuration options
    options = ( )

    def open(self):
        self.linter.add_stats(total_lines=0, code_lines=0,
                              docstring_lines=0, comment_lines=0,
                              empty_lines=0)
        self.stats = self.linter.stats
        
    def process_tokens(self, tokens):
        lines = {}
        i = 0
        tokens = list(tokens)
        while i < len(tokens):
            i, lines_number, type = get_type(tokens, i)
            self.stats['total_lines'] += lines_number
            self.stats[type] += lines_number

    def make_stats(self, old_stats):
        """ calculate percentage of code / doc / comment / empty
        """
        stats = self.stats
        total_lines = stats['total_lines']
        if not total_lines:
            return
        descr = '%s lines have been analyzed' % total_lines
        sect = SectionLayout('Raw metrics', descr)
        self._layouts.append(sect)
        lines = [('type', 'number', '%', 'previous', 'difference')]
        for type in ('code', 'docstring', 'comment', 'empty'):
            key = type + '_lines'
            total = self.stats[key]
            percent = float(total * 100) / total_lines
            old = old_stats.get(key, None)
            if old is not None:
                diff_str = diff_string(old, total)
            else:
                old, diff_str = 'NC', 'NC'
            lines.append((type, str(total), '%.2f' % percent,
                            str(old), diff_str))
        sect.append(TableLayout(lines, row_headers=1))
                    
        
JUNK = (tokenize.NL, tokenize.INDENT, tokenize.NEWLINE, tokenize.ENDMARKER)
import token
def get_type(tokens, start_index):
    i = start_index
    type, tok, start, end, line = tokens[i]
    pos = start
    line_type = None
    while i < len(tokens) and tokens[i][2][0] == start[0]:
        type, tok, dummy, pos, line = tokens[i]
        if line_type is None:
            if type == tokenize.STRING:
                line_type = 'docstring_lines'
            elif type == tokenize.COMMENT:
                line_type = 'comment_lines'
            elif type in JUNK:
                pass
            else:
                line_type = 'code_lines'
        i += 1
        
    if line_type is None:
        line_type = 'empty_lines'
    elif i < len(tokens) and tokens[i][0] == token.NEWLINE:
        i += 1
    return i, pos[0] - start[0] + 1, line_type
    

def register(linter):
    """ required method to auto register this checker """
    linter.register_checker(RawMetricsChecker(linter))
                
