# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
""" Copyright (c) 2000-2003 LOGILAB S.A. (Paris, FRANCE).
 http://www.logilab.fr/ -- mailto:contact@logilab.fr

utilities methods and classes for reporters
"""

__revision__ = "$Id: __init__.py,v 1.2 2003/05/28 15:59:53 syt Exp $"


CMPS = ['=', '-', '+']

def diff_string(old, new):
    """ given a old and new value, return a string representing the difference
    """
    try:
        diff = abs(old - new)
        diff_str = "%s%s" % (CMPS[old.__cmp__(new)], diff or '')
    except Exception, e:
        # the int.__cmp__ doesn't work with python < 2.2
        diff_str = str(e)
    return diff_str


class BaseReporter:
    """ base class for reporters """

    def display_results(self, layout):
        """ display results encapsulated in the layout tree
        """
        self.section = 0
        self._display(layout)
        
    def _display(self, layout):
        """ recurse on the layout tree and call their accept method
        (see the Visitor pattern)
        """
        layout.accept(self)
        for child in layout.children:
            self._display(child)
        try:
            layout.accept(self, close=1)
        except TypeError:
            pass
        
    def visit_sectionlayout(self, layout, close=0):
        """ maintain a section level counter """
        if close:
            self.section -= 1
        else:
            self.section += 1


def format_path(path):
    """ return a string representing a path in the source code
    """
    return '.'.join([p[1] for p in path])

def split_path(path):
    """ return 2 strings representing a path in the source code :
     a module and an object in this module
    """
    if path:
        return path[0][1],  '.'.join([p[1] for p in path[1:]])
    return '',''
        
