# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
""" Copyright (c) 2000-2003 LOGILAB S.A. (Paris, FRANCE).
 http://www.logilab.fr/ -- mailto:contact@logilab.fr

HTML reporter
"""

__revision__ = "$Id: html.py,v 1.2 2003/06/02 08:15:36 syt Exp $"

import sys
from logilab.pylint.interfaces import IReporter
from logilab.pylint.reporters import BaseReporter
from logilab.pylint.layouts import SectionLayout, TableLayout

class HTMLReporter(BaseReporter):

    __implements____ = IReporter

    def __init__(self, output=sys.stdout):
        self.msgs = []
        self.out = output

    def add_message(self, type, module, object, line, msg):
        """ manage message of different type and in the context of path """
        if type == 'info':
            # print informal messages on stderr
            print >> sys.stderr, msg
        else:
            self.msgs.append((type, module, object, str(line), msg))

    def display_results(self, layout):
        if self.msgs:
            # add stocked messages to the layout
            self.msgs.insert(0, ('type', 'module', 'object', 'line', 'message'))
            sect = SectionLayout('Messages')
            layout.append(sect)
            sect.append(TableLayout(self.msgs, row_headers=1))
            self.msgs = []
        BaseReporter.display_results(self, layout)
                    
    def visit_sectionlayout(self, layout, close=0):
        BaseReporter.visit_sectionlayout(self, layout, close)
        if close:
            print >>self.out, '</div>'
        else:
            print >>self.out, '<div>'
            print >>self.out, '<h%s>%s</h%s>' % (self.section,
                                                 layout.title.capitalize(),
                                                 self.section)
            if layout.description:
                print >>self.out, '<p>'
                print >>self.out, layout.description
                print >>self.out, '</p>'

    def visit_tablelayout(self, layout):
        print >>self.out, '<table>'
        for i in range(len(layout.data)):
            line = layout.data[i]
            print >>self.out, '<tr>'
            for j in range(len(line)):
                cell = line[j]
                if (layout.col_headers and i == 0) or \
                   (layout.col_headers and j == 0):
                    print >>self.out, '<th>%s</th>' % cell
                else:
                    print >>self.out, '<td>%s</td>' % cell
            print >>self.out, '</tr>'
        print >>self.out, '</table>'
        

    def visit_verbatimlayout(self, layout):
        print >>self.out, '<pre>'
        print >>self.out, layout.data
        print >>self.out, '</pre>'
