# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
""" Copyright (c) 2000-2003 LOGILAB S.A. (Paris, FRANCE).
 http://www.logilab.fr/ -- mailto:contact@logilab.fr

Plain text reporter
"""

__revision__ = "$Id: text.py,v 1.3 2003/08/21 10:33:33 syt Exp $"

import sys
from logilab.pylint.interfaces import IReporter
from logilab.pylint.reporters import BaseReporter

TITLE_UNDERLINES = ['', '=', '-', '.']

class TextReporter(BaseReporter):
    """ report messages and layouts in plain text
    """
    
    __implements____ = IReporter
    
    def __init__(self, output=sys.stdout):
        self.out = output
        self._modules = {}

    def add_message(self, type, module, object, line, msg):
        """ manage message of different type and in the context of path """
        if type == 'info':
            # print informal messages on stderr
            print >> sys.stderr, msg
        elif type == 'fatal':
            print >>self.out, '!!!!! Fatal: %s' % (msg)
        else:
            if not self._modules.has_key(module):
                print '************* Module', module
                self._modules[module] = 1
            if object:
                object = ':%s' % object
            sigle = type == 'warning' and 'W' or 'E'
            print >>self.out, '%s:%3s%s: %s' % (sigle, line, object, msg)

    def display_results(self, layout):
        print >>self.out
        BaseReporter.display_results(self, layout)
    
    def visit_sectionlayout(self, layout, close=0):
        BaseReporter.visit_sectionlayout(self, layout, close)
        if not close:
            title = layout.title.capitalize()
            print >>self.out, title
            print >>self.out, TITLE_UNDERLINES[self.section] * len(title)
            if layout.description:
                print >>self.out
                print >>self.out, layout.description
            if layout.children:
                print >>self.out
        else:
            print >>self.out
            print >>self.out

    def visit_tablelayout(self, layout):
        cols_size = [size+1 for size in layout.get_columns_size()]
        format_strings = ' '.join(['%%-%ss'] * len(cols_size))
        format_strings = format_strings % tuple(cols_size)
        format_strings = format_strings.split(' ')
        for i in range(len(layout.data)):
            line = layout.data[i]
            for j in range(len(line)):
                cell = line[j]
                if (layout.row_headers and i == 0) or \
                   (layout.col_headers and j == 0):
                    print >>self.out, format_strings[j] % cell.upper(),
                else:
                    print >>self.out, format_strings[j] % cell,
            print >>self.out

    def visit_verbatimlayout(self, layout):
        print >>self.out, layout.data
