# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
""" Copyright (c) 2000-2003 LOGILAB S.A. (Paris, FRANCE).
 http://www.logilab.fr/ -- mailto:contact@logilab.fr

functional tests
"""
__revision__ = '$Id: func_test.py,v 1.8 2003/10/10 09:13:12 syt Exp $'

import unittest
from utils import get_tests_info, fix_path, TestReporter

from logilab.pylint.lint import PyLinter
from logilab.pylint import checkers
linter = PyLinter()
linter.config.persistent = 0
checkers.initialize(linter)


class LintTest(unittest.TestCase):
        
    def test_functionality(self):
        linter.reporter = reporter = TestReporter()
        linter.check('input.'+self.module)
        if self.module.startswith('func_noerror_'):
            expected = ''
        else:
            output = open(self.output)
            expected = output.read()
            output.close()
        got = reporter.out.getvalue()
        self.assertEqual(got, expected, '%s:\n%r != %r' %
                         (self.module, got, expected))
        
def make_tests():
    """generate tests classes from test info
    
    return the list of generated test classes
    """
    tests = []
    for module_file, messages_file in get_tests_info('func_', '.py'):
            
        class LintTestSubclass(LintTest):
            module = module_file.replace('.py', '')
            output = messages_file
                
        tests.append(LintTestSubclass)
    return tests

def suite():
    return unittest.TestSuite([unittest.makeSuite(test)
                               for test in make_tests()])

def Run(runner=None):
    testsuite = suite()
    if runner is None:
        runner = unittest.TextTestRunner()
    return runner.run(testsuite)

if __name__=='__main__':
    Run()


