# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
""" Copyright (c) 2000-2003 LOGILAB S.A. (Paris, FRANCE).
 http://www.logilab.fr/ -- mailto:contact@logilab.fr

Check construction

"""

__revision__ = '$Id: test_format.py,v 1.4 2003/09/18 07:35:36 syt Exp $'

import unittest
import sys
from logilab.pylint.checkers.format import STRING_RGX, check_line

class StringRgxTest(unittest.TestCase):
    """test the STRING_RGX regular expression"""
    
    def test_known_values_1(self):
        self.assertEqual(STRING_RGX.sub('', '"yo"'), '')
        
    def test_known_values_2(self):
        self.assertEqual(STRING_RGX.sub('', "'yo'"), '')
        
    def test_known_values_3(self):
        self.assertEqual(STRING_RGX.sub('', '"""yo"""'), '')
        
    def test_known_values_4(self):
        self.assertEqual(STRING_RGX.sub('', "'''yo'''"), '')
        
    def test_known_values_5(self):
        self.assertEqual(STRING_RGX.sub('', r'"yo\"yo"'), '')
        
    def test_known_values_6(self):
        self.assertEqual(STRING_RGX.sub('', r"'yo\'yo'"), '')
        
    def test_known_values_7(self):
        self.assertEqual(STRING_RGX.sub('', '"yo"upi"yo"upi'), 'upiupi')

    def test_known_values_8(self):
        self.assertEqual(STRING_RGX.sub('', "'yo\\'yo\\"), '')
        
    def test_known_values_9(self):
        self.assertEqual(STRING_RGX.sub('', '"yoyo\\'), '')

    def test_known_values_10(self):
        self.assertEqual(STRING_RGX.sub('', 'self.filterFunc = eval(\'lambda %s: %s\'%(\',\'.join(variables),formula),{},{})'),
                         'self.filterFunc = eval(%(.join(variables),formula),{},{})')
        
    def test_known_values_11(self):
        self.assertEqual(STRING_RGX.sub('', 'cond_list[index] = OLD_PROG.sub(r\'getattr(__old__,"\1")\',cond)'),
                         'cond_list[index] = OLD_PROG.sub(r,cond)')
        
        
class ChecklineFunctionTest(unittest.TestCase):
    """test the check_line method"""
    
    def test_known_values_opspace_1(self):
        self.assertEqual(check_line('a=1'), '''Operator not preceded by a space
a=1
 ^''')
        
    def test_known_values_opspace_2(self):
        self.assertEqual(check_line('a= 1'), '''Operator not preceded by a space
a= 1
 ^''')
        
    def test_known_values_opspace_3(self):
        self.assertEqual(check_line('a =1'), '''Operator not followed by a space
a =1
  ^''')
    def test_known_values_opspace_4(self):
        self.assertEqual(check_line('f(a=1)'), None)

        
    def test_known_values_colonnl_1(self):
        self.assertEqual(check_line('if a: a = 1'), '''Colon not followed by a new line
if a: a = 1
    ^^^^^^^''')
        
    def test_known_values_colonnl_2(self):
        self.assertEqual(check_line('a[:1]'), None)
        
    def test_known_values_colonnl_3(self):
        self.assertEqual(check_line('a[1:]'), None)
        
    def test_known_values_colonnl_4(self):
        self.assertEqual(check_line('a[1:2]'), None)

    def test_known_values_colonnl_5(self):
        self.assertEqual(check_line('def intersection(list1, list2):'), None)

    def test_known_values_colonnl_6(self):
        self.assertEqual(check_line('def intersection(list1, list2):\n'), None)

    def test_known_values_colonnl_7(self):
        self.assertEqual(check_line('if file[:pfx_len] == path:\n'), None)

    def test_known_values_colonnl_8(self):
        self.assertEqual(check_line('def intersection(list1, list2): pass\n'), '''Colon not followed by a new line
def intersection(list1, list2): pass
                              ^^^^^^''')

    def test_known_values_colonnl_9(self):
        self.assertEqual(check_line('if file[:pfx_len[1]] == path:\n'), None)

    def test_known_values_colonnl_10(self):
        self.assertEqual(check_line('if file[pfx_len[1]] == path:\n'), None)

        
    def test_known_values_commaspace_1(self):
        self.assertEqual(check_line('a, b = 1,2'), '''Comma not followed by a space
a, b = 1,2
        ^^''')

        
    def test_known_values_instring_1(self):
        self.assertEqual(check_line('f("a=1")'), None)
        
    def test_known_values_instring_2(self):
        self.assertEqual(check_line('print >>1, ("a:1")'), '''Operator not followed by a space
print >>1, ("a:1")
       ^''')

    def test_known_values_all_1(self):
        self.assertEqual(check_line("self.filterFunc = eval('lambda %s: %s'%(','.join(variables),formula),{},{})"),
                         '''Comma not followed by a space
self.filterFunc = eval('lambda %s: %s'%(','.join(variables),formula),{},{})
                                                           ^^''')

        
def suite():
    """return the unitest suite"""
    loader = unittest.TestLoader()
    testsuite = loader.loadTestsFromModule(sys.modules[__name__])
    return testsuite

def Run(runner=None):
    """run tests"""
    testsuite = suite()
    if runner is None:
        runner = unittest.TextTestRunner()
        # uncomment next line to write tests results in a file
        #runner.__init__(open('tests.log','w+'))    
    return runner.run(testsuite)
        
if __name__ == '__main__':
    Run()
